# Forward Collision Warning - core part

Early collision warning Network Application for Transportation use case - core part.
The package contains core modules for Forward Collision Warning, including object detector,
image tracker, visualisation and standalone example (fcw_example). It requires fcw-core-utils.

